isOpen property
bool
get
isOpen
true while the underlying socket is open and not yet closed.
Implementation
bool get isOpen => _opened && !_closed;
true while the underlying socket is open and not yet closed.
bool get isOpen => _opened && !_closed;