selectedSubprotocol property

String? get selectedSubprotocol

Subprotocol the server actually selected during the handshake (null when the socket has not been opened yet).

Implementation

String? get selectedSubprotocol => _ws?.protocol;